/**
 * Executes an action and checks for an element to be re-rendered on the page.
 *
 * Useful to check the action elements on the frontend, which rerender the
 * component without reloading the page.
 *
 * @param {object} browser
 *   Nightwatch browser instance.
 * @param {function} action
 *   The action to perform.
 * @param {object} checkElementSelector
 *   The selector to check the element for disappear and appear.
 */
module.exports = function performAndWaitForReRender(
  browser,
  action,
  checkElementSelector,
) {
  let elId;
  let isElReloaded = false;
  browser
    .findElement(checkElementSelector, (result) => {
      elId = result.value.getId();
    })
    .perform(action(browser))
    .perform(async () => {
      for (let i = 0; i < 10; i++) {
        // eslint-disable-next-line no-await-in-loop
        await browser.waitForElementVisible(checkElementSelector);
        // eslint-disable-next-line no-await-in-loop
        const elReloaded = await browser.findElement(checkElementSelector);
        if (elReloaded.getId() !== elId) {
          isElReloaded = true;
          break;
        }
        browser.pause(100);
      }
      if (!isElReloaded) {
        throw new Error(
          `The element "${checkElementSelector}" was not rerendered.`,
        );
      }
      return true;
    });
};
