const assert = require('assert');
const performAndWaitForReRender = require('../Lib/performAndWaitForReRender');

module.exports = {
  '@tags': ['select_number_widget'],

  before(browser) {
    browser.drupalInstall({
      installProfile: 'select_number_widget_test_profile',
    });
  },
  after(browser) {
    browser.drupalUninstall();
  },

  'Add Decimal Field to Basic Page and Set Widget Step': (browser) => {
    const prefix = 'P:';
    const suffix = ':S';
    const minVal = -3;
    const maxVal = 2;
    const step = 0.25;
    const dropdownValuesExpected = [];
    for (let i = minVal; i <= maxVal; i += step) {
      const value = `${prefix}${i.toString()}${suffix}`;
      dropdownValuesExpected.push(value);
    }
    const dropdownValuesActual = [];
    browser.drupalLoginAsAdmin(() => {
      browser
        // Create a new content type "test"
        .drupalRelativeURL('/admin/structure/types/add')
        .setValue('#edit-name', 'Test')
        .click('#edit-save-continue')

        // Navigate to Structure > Content types > Basic page > Manage fields.
        .drupalRelativeURL(
          '/admin/structure/types/manage/test/fields/add-field',
        )

        // Add a Number(decimal) field to the node.
        .click('input[value="number"]')
        .click('#edit-submit')
        .setValue('#edit-label', 'Decimal Test')
        .click('input[value="decimal"]')
        .click('#edit-submit')

        // Set the field max-min values.
        .setValue('#edit-settings-min', minVal)
        .setValue('#edit-settings-max', maxVal)
        .setValue('#edit-settings-prefix', prefix)
        .setValue('#edit-settings-suffix', suffix)
        .click('#edit-submit')

        // Set the widget to Select Number Widget and set settings.
        .drupalRelativeURL('/admin/structure/types/manage/test/form-display')
        .perform(
          performAndWaitForReRender(
            browser,
            (browser) => {
              browser.setValue(
                '#edit-fields-field-decimal-test-type',
                'select_number_widget',
              );
            },
            '[data-drupal-selector="edit-fields-field-decimal-test-settings-edit"]',
          ),
        )
        .click(
          '[data-drupal-selector="edit-fields-field-decimal-test-settings-edit"]',
        )
        .waitForElementVisible(
          '[data-drupal-selector="edit-fields-field-decimal-test-settings-edit-form-settings-step"]',
        )
        .setValue(
          '[data-drupal-selector="edit-fields-field-decimal-test-settings-edit-form-settings-step"]',
          step,
        )
        .click(
          '[data-drupal-selector="edit-fields-field-decimal-test-settings-edit-form-actions-save-settings"]',
        )
        .waitForElementVisible(
          '[data-drupal-selector="edit-fields-field-decimal-test"]',
        )
        .assert.textContains(
          '[data-drupal-selector="edit-fields-field-decimal-test"] .field-plugin-summary',
          `Step: ${step}`,
          'Step value set correctly.',
        )
        .click('#edit-submit')

        // Check the dropdown values in the field on the node add form
        .drupalRelativeURL('/node/add/test')
        .findElements(
          'css selector',
          `[data-drupal-selector="edit-field-decimal-test-0-value"] option`,
          (result) => {
            result.value.forEach((option) => {
              // eslint-disable-next-line max-nested-callbacks
              browser.elementIdText(option.getId(), (textResult) => {
                dropdownValuesActual.push(textResult.value);
              });
            });
          },
        )
        .perform(() => {
          assert.deepEqual(dropdownValuesActual, dropdownValuesExpected);
        });
    });
  },
};
